summaryrefslogtreecommitdiffstats
path: root/generic
diff options
context:
space:
mode:
authorvincentdarley <vincentdarley>2002-07-18 15:09:44 (GMT)
committervincentdarley <vincentdarley>2002-07-18 15:09:44 (GMT)
commit20b4ff09da18675ea2feab59089754f481ec34ee (patch)
tree829643419109b08ba493bfc1e9aad427e7ce0bb9 /generic
parent48c1f1f624f1e8a2956e0dca4270bf1317fb7dce (diff)
downloadtcl-20b4ff09da18675ea2feab59089754f481ec34ee.zip
tcl-20b4ff09da18675ea2feab59089754f481ec34ee.tar.gz
tcl-20b4ff09da18675ea2feab59089754f481ec34ee.tar.bz2
load comments and clientData replacement
Diffstat (limited to 'generic')
-rw-r--r--generic/tclIOUtil.c18
-rw-r--r--generic/tclInt.h7
2 files changed, 14 insertions, 11 deletions
diff --git a/generic/tclInt.h b/generic/tclInt.h
index 8f67d45..7400ce0 100644
--- a/generic/tclInt.h
+++ b/generic/tclInt.h
@@ -12,7 +12,7 @@
* See the file "license.terms" for information on usage and redistribution
* of this file, and for a DISCLAIMER OF ALL WARRANTIES.
*
- * RCS: @(#) $Id: tclInt.h,v 1.104 2002/07/18 15:06:54 vincentdarley Exp $
+ * RCS: @(#) $Id: tclInt.h,v 1.105 2002/07/18 15:09:44 vincentdarley Exp $
*/
#ifndef _TCLINT
@@ -1761,7 +1761,10 @@ EXTERN void TclpInitPlatform _ANSI_ARGS_((void));
EXTERN void TclpInitUnlock _ANSI_ARGS_((void));
EXTERN int TclpLoadFile _ANSI_ARGS_((Tcl_Interp *interp,
Tcl_Obj *pathPtr,
- TclLoadHandle *loadHandle,
+ CONST char *sym1, CONST char *sym2,
+ Tcl_PackageInitProc **proc1Ptr,
+ Tcl_PackageInitProc **proc2Ptr,
+ ClientData *clientDataPtr,
Tcl_FSUnloadFileProc **unloadProcPtr));
EXTERN Tcl_Obj* TclpObjListVolumes _ANSI_ARGS_((void));
EXTERN void TclpMasterLock _ANSI_ARGS_((void));
diff --git a/generic/tclIOUtil.c b/generic/tclIOUtil.c
index c875292..c14fd1f 100644
--- a/generic/tclIOUtil.c
+++ b/generic/tclIOUtil.c
@@ -17,7 +17,7 @@
* See the file "license.terms" for information on usage and redistribution
* of this file, and for a DISCLAIMER OF ALL WARRANTIES.
*
- * RCS: @(#) $Id: tclIOUtil.c,v 1.56 2002/07/17 20:00:44 vincentdarley Exp $
+ * RCS: @(#) $Id: tclIOUtil.c,v 1.57 2002/07/18 15:13:26 vincentdarley Exp $
*/
#include "tclInt.h"
@@ -514,7 +514,7 @@ static Tcl_FSUnloadFileProc FSUnloadTempFile;
* operation when we want to unload the code.
*/
typedef struct FsDivertLoad {
- ClientData clientData;
+ TclLoadHandle loadHandle;
Tcl_FSUnloadFileProc *unloadProcPtr;
Tcl_Obj *divertedFile;
Tcl_Filesystem *divertedFilesystem;
@@ -2557,13 +2557,13 @@ Tcl_FSLoadFile(interp, pathPtr, sym1, sym2, proc1Ptr, proc2Ptr,
* Tcl_DecrRefCount(perm);
*
*/
- ClientData newClientData = NULL;
+ TclLoadHandle newLoadHandle = NULL;
Tcl_FSUnloadFileProc *newUnloadProcPtr = NULL;
FsDivertLoad *tvdlPtr;
int retVal;
retVal = Tcl_FSLoadFile(interp, copyToPtr, sym1, sym2,
- proc1Ptr, proc2Ptr, &newClientData,
+ proc1Ptr, proc2Ptr, &newLoadHandle,
&newUnloadProcPtr);
if (retVal != TCL_OK) {
/* The file didn't load successfully */
@@ -2594,7 +2594,7 @@ Tcl_FSLoadFile(interp, pathPtr, sym1, sym2, proc1Ptr, proc2Ptr,
* us to cleanup the diverted load completely, on
* platforms which allow proper unloading of code.
*/
- tvdlPtr->clientData = newClientData;
+ tvdlPtr->loadHandle = newLoadHandle;
tvdlPtr->unloadProcPtr = newUnloadProcPtr;
/* copyToPtr is already incremented for this reference */
tvdlPtr->divertedFile = copyToPtr;
@@ -2689,13 +2689,13 @@ TclpLoadFile(interp, pathPtr, sym1, sym2, proc1Ptr, proc2Ptr,
*---------------------------------------------------------------------------
*/
static void
-FSUnloadTempFile(clientData)
- ClientData clientData; /* ClientData returned by a previous call
- * to Tcl_FSLoadFile(). The clientData is
+FSUnloadTempFile(loadHandle)
+ TclLoadHandle loadHandle; /* loadHandle returned by a previous call
+ * to Tcl_FSLoadFile(). The loadHandle is
* a token that represents the loaded
* file. */
{
- FsDivertLoad *tvdlPtr = (FsDivertLoad*)clientData;
+ FsDivertLoad *tvdlPtr = (FsDivertLoad*)loadHandle;
/*
* This test should never trigger, since we give
* the client data in the function above.